(function() {
  var coffee, extend, fs, util, vm;
  coffee = require('coffee-script');
  fs = require('fs');
  util = require('util');
  vm = require('vm');
  exports.compileFile = function(options) {
    var fileName, settings;
    settings = {
      afterWriteFile: function(fileName, newFileName) {},
      errorWriteFile: function(err, fileName, newFileName) {},
      fileName: void 0,
      mappings: {},
      newFilename: void 0
    };
    if (typeof options === 'string') {
      fileName = options;
    } else {
      extend(settings, options);
      fileName = settings.fileName;
    }
    return fs.readFile(fileName, function(err, data) {
      var css, js, newFileName, sandbox;
      try {
        js = coffee.compile(data.toString().trim());
        sandbox = {
          exports: {},
          require: require
        };
        vm.runInNewContext(js, sandbox);
        css = exports.compileObject(sandbox.exports.css, options.mappings);
        newFileName = settings.newFilename || fileName.replace(/\.css\.coffee$/i, '.css');
        return fs.writeFile(newFileName, css, settings.afterWriteFile(fileName, newFileName));
      } catch (err) {
        return settings.errorWriteFile(err, fileName, newFileName);
      }
    });
  };
  exports.compileObject = function(cssObject, mappings) {
    var compileCssList, outputList;
    mappings || (mappings = {});
    outputList = [];
    compileCssList = function(cssObject) {
      var declarationText, declarations, iterateDeclarations, nestedSelectors, selector, _results;
      _results = [];
      for (selector in cssObject) {
        declarations = cssObject[selector];
        declarationText = [];
        nestedSelectors = {};
        iterateDeclarations = function(d) {
          var cssProperty, key, value, _results2;
          _results2 = [];
          for (key in d) {
            value = d[key];
            _results2.push(typeof value === 'object' ? nestedSelectors["" + selector + " " + key] = value : mappings[key] != null ? iterateDeclarations(mappings[key](value)) : (cssProperty = key.replace(/[A-Z]/g, function(s) {
              return '-' + s.toLowerCase();
            }), declarationText.push("  " + cssProperty + ": " + value + ";")));
          }
          return _results2;
        };
        iterateDeclarations(declarations);
        outputList.push("" + selector + " {\n" + (declarationText.join('\n')) + "\n}");
        _results.push(compileCssList(nestedSelectors));
      }
      return _results;
    };
    compileCssList(cssObject);
    return outputList.join('\n');
  };
  extend = function(object, properties) {
    var key, value;
    for (key in properties) {
      value = properties[key];
      object[key] = value;
    }
    return object;
  };
}).call(this);
